@@ -11,12 +11,17 @@ from typing import AsyncGenerator, Callable
 
 from httpx import AsyncClient
 
+from .home import Home, Room, ThermMode, TemperatureControlMode, ThermSetpointMode
 from .base import BaseClient
 from .errors import NonOkResponseException, UnsuportedArgumentsException
 from .thermostat_auth import ThermostatAuth
 from .time import now
 from .token import Token, TokenStore
 
+_HOMES_DATA_PATH = "api/homesdata"
+_SET_HOME_DATA = "api/sethomedata"
+_SET_STATE = "syncapi/v1/setstate"
+
 _GET_THERMOSTATS_DATA_PATH = "api/getthermostatsdata"
 _GET_MEASURE_PATH = "api/getmeasure"
 _SET_SYSTEM_MODE_PATH = "api/setsystemmode"
@@ -28,6 +33,7 @@ _MODIFY_DEVICE_PARAM_PATH = "api/modifydeviceparam"
 _VAILLANT_DEVICE_TYPE = "NAVaillant"
 _VAILLANT_DATA_AMOUNT = "app"
 _VAILLANT_SYNC_DEVICE_ID = "all"
+_VAILLANT_APP_ID = "app_thermostat_vaillant"
 _RESPONSE_STATUS_OK = "ok"
 _SETPOINT_DEFAULT_DURATION_MINS = 120
 
@@ -70,6 +76,146 @@ class ThermostatClient(BaseClient):
 
         super().__init__(client, ThermostatAuth(token_store))
 
+    async def async_get_homes_data(self) -> list[Home]:
+        """
+        Get homes data from the Netatmo API.
+
+        On success, returns a list of homes with their device data. On error, throws an exception.
+        """
+        path = _HOMES_DATA_PATH
+        data = {
+            "app_type": _VAILLANT_APP_ID,
+            "app_identifier": _VAILLANT_APP_ID,
+            "sync_measurements": True,
+        }
+
+        body = await self._post(
+            path,
+            json=data,
+        )
+
+        if body["status"] != _RESPONSE_STATUS_OK:
+            raise NonOkResponseException(
+                "Unknown response error. Check the log for more details.", path=path, data=data, body=body
+            )
+
+        return [Home(**home) for home in body["body"]["homes"]]
+
+    async def async_set_home_data(
+        self,
+        home_id: str,
+        temperature_control_mode: TemperatureControlMode,
+        therm_mode: ThermMode | None = None,
+    ) -> None:
+        """
+        Change the thermostat's system mode to the provided value.
+
+        On success, returns nothing. On error, throws an exception.
+        """
+
+        path = _SET_HOME_DATA
+        data = {
+            "home": {
+                "id": home_id,
+                "temperature_control_mode": temperature_control_mode.value,
+            },
+            "app_identifier": _VAILLANT_APP_ID,
+        }
+
+        if therm_mode is not None:
+            data["therm_mode"] = therm_mode.value
+
+        body = await self._post(
+            path,
+            json=data,
+        )
+
+        if body["status"] != _RESPONSE_STATUS_OK:
+            raise NonOkResponseException(
+                "Unknown response error. Check the log for more details.", path=path, data=data, body=body
+            )
+
+    async def async_set_state_for_room(
+        self,
+        home_id: str,
+        room_id: str,
+        therm_setpoint_mode: ThermSetpointMode,
+        therm_setpoint_temperature: float | None = None,
+        therm_setpoint_end_time: datetime | None = None,
+    ) -> None:
+        """
+        Activate or deactivate thermostat's minor mode, for the provided duration and temperature.
+
+        On success, returns nothing. On error, throws an exception.
+        """
+
+        path = _SET_STATE
+        data = {
+            "home": {
+                "id": home_id,
+                "rooms": [{
+                    "id": room_id,
+                    "therm_setpoint_mode": therm_setpoint_mode.value,
+                }],
+            },
+            "app_identifier": _VAILLANT_APP_ID,
+        }
+
+        endtime = self._get_setpoint_endtime(
+            therm_setpoint_mode, therm_setpoint_end_time
+        )
+        if endtime is not None:
+            data["home"]["rooms"][0]["therm_setpoint_end_time"] = endtime
+
+        temp = self._get_setpoint_temp(
+            therm_setpoint_mode, therm_setpoint_temperature)
+        if temp is not None:
+            data["home"]["rooms"][0]["therm_setpoint_temperature"] = temp
+
+        body = await self._post(
+            path,
+            json=data,
+        )
+
+        if body["status"] != _RESPONSE_STATUS_OK:
+            raise NonOkResponseException(
+                "Unknown response error. Check the log for more details.", path=path, data=data, body=body
+            )
+
+    async def async_set_state_for_module(
+        self,
+        home_id: str,
+        module_id: str,
+        dhw_enabled: bool,
+    ) -> None:
+        """
+        Activate or deactivate thermostat's minor mode, for the provided duration and temperature.
+
+        On success, returns nothing. On error, throws an exception.
+        """
+
+        path = _SET_STATE
+        data = {
+            "home": {
+                "id": home_id,
+                "modules": [{
+                    "id": module_id,
+                    "dhw_enabled": dhw_enabled,
+                }],
+            },
+            "app_identifier": _VAILLANT_APP_ID,
+        }
+
+        body = await self._post(
+            path,
+            json=data,
+        )
+
+        if body["status"] != _RESPONSE_STATUS_OK:
+            raise NonOkResponseException(
+                "Unknown response error. Check the log for more details.", path=path, data=data, body=body
+            )
+
     async def async_get_thermostats_data(self) -> list[Device]:
         """
         Get thermostat data from the Netatmo API.
@@ -84,7 +230,7 @@ class ThermostatClient(BaseClient):
             "sync_device_id": _VAILLANT_SYNC_DEVICE_ID,
         }
 
-        body = await self._post(
+        body = await self._old_post(
             path,
             data=data,
         )
@@ -126,7 +272,7 @@ class ThermostatClient(BaseClient):
         if limit is not None:
             data["limit"] = limit
 
-        body = await self._post(
+        body = await self._old_post(
             path,
             data=data,
         )
@@ -141,75 +287,6 @@ class ThermostatClient(BaseClient):
             for measurement in body["body"]
         ]
 
-    async def async_set_system_mode(
-        self, device_id: str, module_id: str, system_mode: SystemMode
-    ) -> None:
-        """
-        Change the thermostat's system mode to the provided value.
-
-        On success, returns nothing. On error, throws an exception.
-        """
-
-        path = _SET_SYSTEM_MODE_PATH
-        data = {
-            "device_id": device_id,
-            "module_id": module_id,
-            "system_mode": system_mode.value,
-        }
-
-        body = await self._post(
-            path,
-            data=data,
-        )
-
-        if body["status"] != _RESPONSE_STATUS_OK:
-            raise NonOkResponseException(
-                "Unknown response error. Check the log for more details.", path=path, data=data, body=body
-            )
-
-    async def async_set_minor_mode(
-        self,
-        device_id: str,
-        module_id: str,
-        setpoint_mode: SetpointMode,
-        activate: bool,
-        setpoint_endtime: datetime | None = None,
-        setpoint_temp: float | None = None,
-    ) -> None:
-        """
-        Activate or deactivate thermostat's minor mode, for the provided duration and temperature.
-
-        On success, returns nothing. On error, throws an exception.
-        """
-
-        path = _SET_MINOR_MODE_PATH
-        data = {
-            "device_id": device_id,
-            "module_id": module_id,
-            "setpoint_mode": setpoint_mode.value,
-            "activate": activate,
-        }
-
-        endtime = self._get_setpoint_endtime(
-            setpoint_mode, activate, setpoint_endtime
-        )
-        if endtime is not None:
-            data["setpoint_endtime"] = endtime
-
-        temp = self._get_setpoint_temp(setpoint_mode, activate, setpoint_temp)
-        if temp is not None:
-            data["setpoint_temp"] = temp
-
-        body = await self._post(
-            path,
-            data=data,
-        )
-
-        if body["status"] != _RESPONSE_STATUS_OK:
-            raise NonOkResponseException(
-                "Unknown response error. Check the log for more details.", path=path, data=data, body=body
-            )
-
     async def async_sync_schedule(
         self,
         device_id: str,
@@ -244,7 +321,7 @@ class ThermostatClient(BaseClient):
             } for time_slot in timetable]),
         }
 
-        body = await self._post(
+        body = await self._old_post(
             path,
             data=data,
         )
@@ -273,7 +350,7 @@ class ThermostatClient(BaseClient):
             "schedule_id": schedule_id,
         }
 
-        body = await self._post(
+        body = await self._old_post(
             path,
             data=data,
         )
@@ -300,7 +377,7 @@ class ThermostatClient(BaseClient):
             "setpoint_default_duration": setpoint_default_duration,
         }
 
-        body = await self._post(
+        body = await self._old_post(
             path,
             data=data,
         )
@@ -328,7 +405,7 @@ class ThermostatClient(BaseClient):
             "dhw": dhw,
         }
 
-        body = await self._post(
+        body = await self._old_post(
             path,
             data=data,
         )
@@ -340,55 +417,45 @@ class ThermostatClient(BaseClient):
 
     def _get_setpoint_endtime(
         self,
-        setpoint_mode: SetpointMode,
-        activate: bool,
+        therm_setpoint_mode: ThermSetpointMode,
         setpoint_endtime: datetime | None = None,
     ) -> int | None:
-        if not activate:
-            if setpoint_endtime is not None:
-                raise UnsuportedArgumentsException(
-                    "Provided arguments for setting endtime are not valid.", setpoint_mode=setpoint_mode, activate=activate, setpoint_endtime=setpoint_endtime
-                )
+        if therm_setpoint_mode == ThermSetpointMode.HOME and setpoint_endtime is not None:
+            raise UnsuportedArgumentsException(
+                "Provided arguments for setting endtime are not valid.", therm_setpoint_mode=therm_setpoint_mode, setpoint_endtime=setpoint_endtime
+            )
+
+        if therm_setpoint_mode == ThermSetpointMode.MANUAL and setpoint_endtime is None:
+            raise UnsuportedArgumentsException(
+                "Provided arguments for setting endtime are not valid.", therm_setpoint_mode=therm_setpoint_mode, setpoint_endtime=setpoint_endtime
+            )
+
+        if setpoint_endtime is None:
             return None
-        else:
-            if setpoint_endtime is None:
-                if setpoint_mode == SetpointMode.MANUAL or setpoint_mode == SetpointMode.HWB:
-                    raise UnsuportedArgumentsException(
-                        "Provided arguments for setting endtime are not valid.", setpoint_mode=setpoint_mode, activate=activate, setpoint_endtime=setpoint_endtime
-                    )
-                return None
-            else:
-                if setpoint_endtime <= now():
-                    raise UnsuportedArgumentsException(
-                        "Provided arguments for setting endtime are not valid.", setpoint_mode=setpoint_mode, activate=activate, setpoint_endtime=setpoint_endtime
-                    )
-                return round(setpoint_endtime.timestamp())
+
+        if setpoint_endtime <= now():
+            raise UnsuportedArgumentsException(
+                "Provided arguments for setting endtime are not valid.", therm_setpoint_mode=therm_setpoint_mode, setpoint_endtime=setpoint_endtime
+            )
+
+        return round(setpoint_endtime.timestamp())
 
     def _get_setpoint_temp(
         self,
-        setpoint_mode: SetpointMode,
-        activate: bool,
+        therm_setpoint_mode: ThermSetpointMode,
         setpoint_temp: float | None = None,
     ) -> float | None:
-        if not activate:
-            if setpoint_temp is not None:
-                raise UnsuportedArgumentsException(
-                    "Provided arguments for setting temp are not valid.", setpoint_mode=setpoint_mode, activate=activate, setpoint_temp=setpoint_temp
-                )
-            return None
-        else:
-            if setpoint_temp is None:
-                if setpoint_mode == SetpointMode.MANUAL:
-                    raise UnsuportedArgumentsException(
-                        "Provided arguments for setting temp are not valid.", setpoint_mode=setpoint_mode, activate=activate, setpoint_temp=setpoint_temp
-                    )
-                return None
-            else:
-                if setpoint_mode != SetpointMode.MANUAL:
-                    raise UnsuportedArgumentsException(
-                        "Provided arguments for setting temp are not valid.", setpoint_mode=setpoint_mode, activate=activate, setpoint_temp=setpoint_temp
-                    )
-                return setpoint_temp
+        if therm_setpoint_mode == ThermSetpointMode.HOME and setpoint_temp is not None:
+            raise UnsuportedArgumentsException(
+                "Provided arguments for setting endtime are not valid.", therm_setpoint_mode=therm_setpoint_mode, setpoint_temp=setpoint_temp
+            )
+
+        if therm_setpoint_mode == ThermSetpointMode.MANUAL and setpoint_temp is None:
+            raise UnsuportedArgumentsException(
+                "Provided arguments for setting endtime are not valid.", therm_setpoint_mode=therm_setpoint_mode, setpoint_temp=setpoint_temp
+            )
+
+        return setpoint_temp
 
 
 class Device:
